@@ -5,15 +5,16 @@
 use crate::testing::TestResult;
 use anyhow::anyhow;
 use async_trait::async_trait;
-use futures::{future::BoxFuture, Stream};
+use futures::future::BoxFuture;
 use serde::Serialize;
 use std::{fs, io::Write, ops::Deref, path::PathBuf, sync::Arc};
 use tokio::sync::OnceCell;
 use toml::value::Value as TomlValue;
 use wasmbus_rpc::{
+    anats,
+    common::{Context, Message, SendOpts, Transport},
     core::{HealthCheckRequest, HealthCheckResponse, HostData, LinkDefinition, WasmCloudEntity},
-    provider::ratsio::{ops::Message as NatsMessage, NatsClient, NatsSid},
-    Context, Message, RpcError, RpcResult, SendOpts, Transport,
+    error::{RpcError, RpcResult},
 };
 
 pub type SimpleValueMap = std::collections::HashMap<String, String>;
@@ -52,8 +53,8 @@ pub struct ProviderProcess {
     pub path: PathBuf,
     pub proc: std::process::Child,
     pub config: TomlMap,
-    pub nats_client: Arc<NatsClient>,
-    pub rpc_client: wasmbus_rpc::RpcClient,
+    pub nats_client: anats::Connection,
+    pub rpc_client: wasmbus_rpc::rpc_client::RpcClient,
     pub timeout_ms: std::sync::Mutex<u64>,
 }
 
@@ -138,12 +139,11 @@ impl ProviderProcess {
     }
 
     /// subscribe to rpc messages from the provider using the established link
-    pub async fn subscribe_rpc(
-        &self,
-    ) -> RpcResult<(NatsSid, impl Stream<Item = NatsMessage> + Send + Sync)> {
-        let subject = wasmbus_rpc::rpc_topic(&self.origin(), &self.host_data.lattice_rpc_prefix);
+    pub async fn subscribe_rpc(&self) -> RpcResult<anats::Subscription> {
+        let subject =
+            wasmbus_rpc::rpc_client::rpc_topic(&self.origin(), &self.host_data.lattice_rpc_prefix);
         self.nats_client
-            .subscribe(subject)
+            .subscribe(&subject)
             .await
             .map_err(|e| wasmbus_rpc::RpcError::Nats(e.to_string()))
     }
@@ -222,6 +222,7 @@ impl Transport for Provider {
 
 impl Deref for Provider {
     type Target = ProviderProcess;
+
     fn deref(&self) -> &Self::Target {
         &self.inner
     }
@@ -280,12 +281,11 @@ pub async fn start_provider_test(config: TomlMap) -> Result<Provider, anyhow::Er
     // set logging level for capability provider with the "RUST_LOG" environment variable,
     // default level is "info"
     let log_level = match config.get("rust_log") {
-        Some(TomlValue::String(level)) if level.parse::<log::Level>().is_ok() => level.to_string(),
-        None => "info".to_string(),
-        Some(x) => {
-            eprintln!("invalid 'rust_log' setting '{}', using 'info'", x);
-            "info".to_string()
+        Some(TomlValue::String(level)) => {
+            eprintln!("Setting provider logging level to {}", &level);
+            level.to_string()
         }
+        _ => "info".to_string(),
     };
     // set RUST_BACKTRACE, if requested
     // default is disabled
@@ -320,6 +320,7 @@ pub async fn start_provider_test(config: TomlMap) -> Result<Provider, anyhow::Er
 
     // provider's stdout is piped through our stdout
     let mut child_proc = std::process::Command::new(&exe_path)
+        .stdout(std::process::Stdio::piped())
         .stdin(std::process::Stdio::piped())
         .env("RUST_LOG", &log_level)
         .env("RUST_BACKTRACE", enable_backtrace)
@@ -334,16 +335,15 @@ pub async fn start_provider_test(config: TomlMap) -> Result<Provider, anyhow::Er
     stdin.write_all(encoded.as_bytes())?;
 
     // Connect to nats
-    let nats_client = NatsClient::new(host_data.nats_options())
-        .await
-        .map_err(|e| {
-            anyhow!(
-                "nats connection to {} failed: {}",
-                &host_data.lattice_rpc_url,
-                e.to_string()
-            )
-        })?;
-    let client = wasmbus_rpc::RpcClient::new(
+    let nats_client = host_data.nats_connect().await.map_err(|e| {
+        anyhow!(
+            "nats connection to {} failed: {}",
+            &host_data.lattice_rpc_url,
+            e.to_string()
+        )
+    })?;
+
+    let client = wasmbus_rpc::rpc_client::RpcClient::new(
         nats_client.clone(),
         &host_data.lattice_rpc_prefix,
         keys,
